I'm tired of typing `git rev-list --count HEAD` all the time, let's call it `qwd q`.

type | to do 
---  | ---
`qwd q` | `git rev-list --count HEAD`
`qwd qw` | `git branch`
`qwd w` | `git log -3`
`qwd wd` | `git diff --cached`

type | to do 
---  | ---
`qwd qwd` | I made some changes, but I don't remember what I did. Create a commit for me.

They don't have a pattern; I just add the commands I use the most.

If you want to give it a try, run `pip install qwd`.

<!-- Dev note: Don't run commands that are destructive or irreversible -->
